@@ -14,7 +14,7 @@ Version 0.13
 
 =cut
 
-our $VERSION = '0.14.' . substr(q$Revision: 9 $, 10); # bump from 5
+our $VERSION = '0.14.' . substr(q$Revision: 12 $, 10); # bump from 10
 
 =head1 SYNOPSIS
 
@@ -108,8 +108,7 @@ sub new {
 
 sub _svnlook {
     my ($self, $cmd, @args) = @_;
-    my $fd;
-    open $fd, '-|', $SVNLOOK, $cmd, $self->{repo}, @{$self->{what}}, @args
+    open my $fd, '-|', $SVNLOOK, $cmd, $self->{repo}, @{$self->{what}}, @args
 	or die "Can't exec svnlook $cmd: $!\n";
     if (wantarray) {
 	my @lines = <$fd>;
